@@ -16,7 +16,7 @@ parser.add_argument("--chunk_index", type=int, help="Chunk index")
 
 # Get arguments from parser
 args = parser.parse_args()
-datasets = json.load(args.datasets_json)
+datasets = json.loads(args.datasets_json)
 raw_data_dir = args.raw_data_dir
 number_chunk = args.number_chunk
 chunk_index = args.chunk_index
