@@ -74,7 +74,7 @@ if output_jsons_path.is_dir():
             )
 
 for dataset in save_datasets:
-    file_data_set = Dataset.File.from_files(path=(datastore, output_jsons + '/' + dataset["pattern"]))
+    file_data_set = Dataset.File.from_files(path=(datastore, save_datastore_path + '/' + dataset["pattern"]))
     file_data_set.register(
         workspace=workspace,
         name=dataset["name"],
